Thread

Struct Thread 

pub struct Thread { /* private fields */ }
A thread is a single sequential flow of control within a program. It has its own call stack and program counter.

References

Implementations

Source

impl Thread

pub fn new(vm: &Weak<VM>, id: u64) -> Arc<Self>

Create a new thread.

pub fn id(&self) -> u64

Get the identifier of the thread.

pub fn vm(&self) -> Result<Arc<VM>>

Get the virtual machine that owns the thread.

Errors

if the virtual machine cannot be accessed.

pub async fn name(&self) -> String

Get the name of the thread.

pub async fn set_name<S: AsRef<str>>(&self, name: S)

Set the name of the thread.

pub async fn java_object(&self) -> Value

Get the Java object for this thread.

pub async fn set_java_object(&self, new_java_object: Value)

Set the Java thread object for this thread.

pub async fn frames(&self) -> Result<Vec<Arc<Frame>>>

Get the frames in the thread.

Errors

if the frames cannot be accessed.

pub async fn current_frame(&self) -> Result<Arc<Frame>>

Get the current frame in the thread.

Errors

if the current frame cannot be accessed.

pub fn interrupt(&self)

Set the thread as interrupted.

pub fn is_interrupted(&self, clear_interrupt: bool) -> bool

Check if the thread is interrupted and clear the interrupt if specified.

pub async fn sleep(&self, duration: Duration) -> bool

Sleep the thread for the specified duration. The sleep is interruptible - if another thread calls interrupt(), this method will return true to indicate the thread was interrupted, clearing the interrupt flag.

Arguments
  • duration - The duration to sleep.
Returns

Returns true if the sleep was interrupted, false if it completed normally.

pub async fn park(&self, is_absolute: bool, time: u64) -> Result<()>

Park the thread. If the permit is available, it will be consumed and the thread will return immediately. If the permit is not available, the thread will be parked until it is unparked or the specified time has elapsed.

Arguments
  • is_absolute - If true, the time parameter is treated as an absolute timestamp (milliseconds since epoch).
  • time - The time to park the thread. If is_absolute is true, this is the absolute timestamp in milliseconds since epoch. If is_absolute is false, this is the relative duration in nanoseconds.
Errors

If the parking operation fails, an error will be returned.

pub fn unpark(&self)

Unpark the thread if it is parked.

pub fn class<'life_self, 'async_recursion, S>( &'life_self self, class_name: S, ) -> Pin<Box<dyn Future<Output = Result<Arc<Class>>> + Send + 'async_recursion>>
where S: 'async_recursion + AsRef<str> + Send, 'life_self: 'async_recursion,

Get a class and ensure it is initialized.

This implements the class initialization procedure as specified in JLS 12.4.2:

  1. If the class is already initialized, return immediately
  2. If the class is in an erroneous state, throw NoClassDefFoundError
  3. If the class is being initialized by the current thread, return (recursive initialization)
  4. If the class is being initialized by another thread, wait and recheck
  5. Mark the class as being initialized by the current thread
  6. Initialize the direct superclass first (recursive)
  7. Execute <clinit> for this class
  8. If <clinit> throws, mark as Erroneous and throw ExceptionInInitializerError
  9. Mark the class as Initialized

Note: This implementation does NOT initialize interfaces as part of class initialization unless explicitly triggered per JLS 12.4.1.

References
Errors

if the class cannot be loaded or initialized

pub async fn invoke<C, M>( &self, class: C, method: M, parameters: &[impl RustValue], ) -> Result<Option<Value>>
where C: AsRef<str> + Send + Sync, M: AsRef<str> + Send + Sync,

Invoke a method. To invoke a method on an object reference, the object reference must be the first parameter in the parameters vector.

Errors

if the method cannot be invoked

pub async fn try_invoke<C, M>( &self, class: C, method: M, parameters: &[impl RustValue], ) -> Result<Value>
where C: AsRef<str> + Send + Sync, M: AsRef<str> + Send + Sync,

Invoke a method. To invoke a method on an object reference, the object reference must be the first parameter in the parameters vector.

Errors

if the method cannot be invoked

pub async fn execute( &self, class: &Arc<Class>, method: &Arc<Method>, parameters: &[impl RustValue], ) -> Result<Option<Value>>

Add a new frame to the thread and invoke the method. To invoke a method on an object reference, the object reference must be the first parameter in the parameters vector.

Errors

if the method cannot be invoked.

pub async fn try_execute( &self, class: &Arc<Class>, method: &Arc<Method>, parameters: &[impl RustValue], ) -> Result<Value>

Add a new frame to the thread and invoke the method. To invoke a method on an object reference, the object reference must be the first parameter in the parameters vector.

Errors

if the method cannot be invoked.

pub async fn object<C, M>( &self, class_name: C, descriptor: M, parameters: &[impl RustValue], ) -> Result<Value>
where C: AsRef<str> + Send + Sync, M: AsRef<str> + Send + Sync,

Create a new VM Object by invoking the constructor of the specified class.

Errors

if the object cannot be created